<?php

/********************
* ADVANCED SETTINGS *
********************/

/**
 * Register settings
 */
function xmlsf_news_register_settings() {
	// register settings
	register_setting( 'xmlsf_news_advanced', 'xmlsf_news_advanced', 'xmlsf_news_sanitize_advanced_settings' );
	register_setting( 'xmlsf_news_license', 'xmlsf_news_license', 'xmlsf_news_sanitize_license' );
	register_setting( 'xmlsf_news_log', 'xmlsf_news_log_clear', 'xmlsf_news_sanitize_log_clear' );

	// replace advanced tab options
	remove_action( 'xmlsf_news_settings_before', 'xmlsf_news_section_advanced_intro' );
	//remove_action( 'xmlsf_news_add_settings', array( 'XMLSF_Admin_Sitemap_News', 'advanced_settings_fields' ) );
	add_action( 'xmlsf_news_settings_before', 'xmlsf_news_advanced_section_intro' );
	add_action( 'xmlsf_news_add_settings', 'xmlsf_news_advanced_add_settings' );

	// add a ping log tab
	add_action( 'xmlsf_news_nav_tabs', 'xmlsf_news_advanced_add_tab_log' );

	// add a license tab
	add_action( 'xmlsf_news_nav_tabs', 'xmlsf_news_advanced_add_tab_license' );
}

/**
 * Add settings sections and fields
 */
function xmlsf_news_advanced_add_settings( $active_tab = '' ) {
	if ( 'advanced' == $active_tab ) {
		// Hierarchical post types
		add_settings_field( 'xmlsf_news_hierarchical', __( 'Hierarchical post types', 'xml-sitemap-feed' ), 'xmlsf_news_hierarchical_field', 'xmlsf_news_advanced', 'news_sitemap_advanced_section' );

		// Keywords
		add_settings_field( 'xmlsf_news_keywords', __('Keywords', 'xml-sitemap-feed' ), 'xmlsf_news_keywords_field', 'xmlsf_news_advanced', 'news_sitemap_advanced_section' );

		// Stock tickers
		add_settings_field( 'xmlsf_news_stock_tickers', __('Stock tickers', 'xml-sitemap-feed' ), 'xmlsf_news_stock_tickers_field', 'xmlsf_news_advanced', 'news_sitemap_advanced_section' );

		// Ping log
		add_settings_field( 'xmlsf_news_ping_log', __('Ping log', 'xml-sitemap-feed' ), 'xmlsf_news_ping_log_field', 'xmlsf_news_advanced', 'news_sitemap_advanced_section' );
	}

	if ( 'log' == $active_tab ) {
		// LOG SECTION
		add_settings_section( 'news_sitemap_log_section', '', '', 'xmlsf_news_log' );

		// Log settings
		add_settings_field( 'xmlsf_news_log_view', __('View log', 'xml-sitemap-feed' ), 'xmlsf_news_log_field', 'xmlsf_news_log', 'news_sitemap_log_section' );

		add_settings_field( 'xmlsf_news_log_clear', __('Clear log', 'xml-sitemap-feed' ), 'xmlsf_news_log_clear_field', 'xmlsf_news_log', 'news_sitemap_log_section' );

	}

	if ( 'license' == $active_tab ) {
		// LICENSE SECTION
		add_settings_section( 'news_sitemap_license_section', '', '', 'xmlsf_news_license' );

		// License key
		add_settings_field( 'xmlsf_news_license_key', '<label for="xmlsf_news_license_key">'.__('License key', 'xml-sitemap-feed' ).'</label>', 'xmlsf_news_license_key_field', 'xmlsf_news_license', 'news_sitemap_license_section' );

		add_settings_field( 'xmlsf_news_license_action', __('License action', 'xml-sitemap-feed' ), 'xmlsf_news_license_action_field', 'xmlsf_news_license', 'news_sitemap_license_section' );

	}
}

/**
 * Hook section intros
 */
function xmlsf_news_advanced_section_intro( $active_tab = '' ) {
	if ( 'advanced' == $active_tab )
		include XMLSF_NEWS_ADV_DIR . '/views/section-advanced-intro.php';
	if ( 'license' == $active_tab )
		include XMLSF_NEWS_ADV_DIR . '/views/section-license-intro.php';
}

/**
 * Settings fields
 */

function xmlsf_news_hierarchical_field() {
  $options = get_option('xmlsf_news_advanced');

	$allow_hierarchical = !empty($options['allow_hierarchical']);

 	// The actual fields for data entry
 	include XMLSF_NEWS_ADV_DIR . '/views/field-news-hierarchical.php';
}

function xmlsf_news_keywords_field() {
	$options = get_option('xmlsf_news_advanced');
	$keywords_from = !empty( $options['keywords_from'] ) ? $options['keywords_from'] : '';

	$options = get_option('xmlsf_news_tags');
	$news_post_type = isset( $options['post_type'] ) && !empty( $options['post_type'] ) ? $options['post_type'] : 'post';

	$taxonomies = xmlsf_news_available_taxonomies( $news_post_type );

	// The actual fields for data entry
	include XMLSF_NEWS_ADV_DIR . '/views/field-news-keywords.php';
}

function xmlsf_news_stock_tickers_field() {
	$options = get_option('xmlsf_news_advanced');

	$stock_tickers = !empty($options['stock_tickers']);

	// The actual fields for data entry
	include XMLSF_NEWS_ADV_DIR . '/views/field-news-stocktickers.php';
}

function xmlsf_news_ping_log_field() {
	$options = get_option('xmlsf_news_advanced');

	$ping_log = !empty($options['ping_log']);
	$ping_log_max = !empty($options['ping_log_max']) && is_numeric($options['ping_log_max']) ? $options['ping_log_max'] : '1000';

	// The actual fields for data entry
	include XMLSF_NEWS_ADV_DIR . '/views/field-news-ping-log.php';
}

function xmlsf_news_log_field() {
	$log = get_option('xmlsf_news_log');

	// The actual fields for data entry
	include XMLSF_NEWS_ADV_DIR . '/views/field-news-log.php';
}

function xmlsf_news_log_clear_field() {
	// The actual fields for data entry
	include XMLSF_NEWS_ADV_DIR . '/views/field-news-log-clear.php';
}

function xmlsf_news_license_key_field() {
	$data = (array) get_option( 'xmlsf_news_license', array() );

	$data = xmlsf_news_check_license( $data );

	$key = isset($data['key']) ? $data['key'] : '';

	$status = isset($data['status']) ? $data['status'] : '';
	$expires = ! empty($data['expires']) ? date_i18n( get_option( 'date_format' ), strtotime( $data['expires'], current_time( 'timestamp' ) ) ) : '';
	$payment_id = ! empty($data['payment_id']) ? $data['payment_id'] : '';
	$error = isset($data['error']) ? $data['error'] : '';
	$account_url = ! empty( $payment_id ) ? trailingslashit( XMLSF_NEWS_ADV_STORE_URL ) . 'account/?action=manage_licenses&payment_id=' . $payment_id : trailingslashit( XMLSF_NEWS_ADV_STORE_URL ) . 'account/';

	// The actual fields for data entry
	include XMLSF_NEWS_ADV_DIR . '/views/field-news-license-key.php';
}

function xmlsf_news_license_action_field() {
	$option = get_option( 'xmlsf_news_license' );
	$status = isset($option['status']) ? $option['status'] : '';
	$payment_id = ! empty($option['payment_id']) ? $option['payment_id'] : '';
	$account_url = ! empty( $payment_id ) ? trailingslashit( XMLSF_NEWS_ADV_STORE_URL ) . 'account/?action=manage_licenses&payment_id=' . $payment_id : trailingslashit( XMLSF_NEWS_ADV_STORE_URL ) . 'account/';

	// The actual fields for data entry
	include XMLSF_NEWS_ADV_DIR . '/views/field-news-license-action.php';
}

/*
 * Tabs
 */

function xmlsf_news_advanced_add_tab_log( $active_tab = '' ) {
	$options = get_option('xmlsf_news_advanced');
	if ( !empty($options['ping_log']) )
		include XMLSF_NEWS_ADV_DIR . '/views/nav-tab-log.php';
}

function xmlsf_news_advanced_add_tab_license( $active_tab = '' ) {
		include XMLSF_NEWS_ADV_DIR . '/views/nav-tab-license.php';
}

/**
 * Check license validity and set nag
 */

function xmlsf_news_license_admin_nag() {
	// retrieve our license key from the DB
	$option = (array) get_option( 'xmlsf_news_license', array() );
	$key = isset( $option['key'] ) ? trim( $option['key'] ) : '';
	$status = isset($option['status']) ? $option['status'] : '';

	if ( empty($key) ) {
		add_action( 'admin_notices',
			function() {
				echo '<div class="notice notice-error fade is-dismissible"><p>';
				printf( /* Translators: Plugin name */ __('You have not yet entered your license key for %s.','xml-sitemap-feed'), __('Google News Advanced','xml-sitemap-feed') );
				echo ' ';
				printf( /* Translators: Plugin name, correct this issue (linked) */
					__('To receive plugin updates, please %s.','xml-sitemap-feed'),
					'<a href="' . admin_url('options-general.php') . '?page=xmlsf_news&tab=license">' . __('correct this issue','xml-sitemap-feed') . '</a>'
				);
				echo '</p></div>';
			}
		);
	} elseif ( 'expired' == $status || 'invalid' == $status ) {
		add_action( 'admin_notices',
			function() {
				echo '<div class="notice notice-error fade is-dismissible"><p>';
				printf( /* Translators: Plugin name */ __('You have an invalid or expired license key for %s.','xml-sitemap-feed'), __('Google News Advanced','xml-sitemap-feed') );
				echo ' ';
				printf( /* Translators: Plugin name, correct this issue (linked) */
					__('To receive plugin updates, please %s.','xml-sitemap-feed'),
					'<a href="' . admin_url('options-general.php') . '?page=xmlsf_news&tab=license">' . __('correct this issue','xml-sitemap-feed') . '</a>'
				);
				echo '</p></div>';
			}
		);
	} elseif ( 'inactive' == $status ) {
		add_action( 'admin_notices',
			function() {
				echo '<div class="notice notice-warning fade is-dismissible"><p>';
				printf( /* Translators: Plugin name */ __('Your license key for %s is not activated for this site.','xml-sitemap-feed'), __('Google News Advanced','xml-sitemap-feed') );
				echo ' ';
				printf( /* Translators: Plugin name, correct this issue (linked) */
					__('To receive plugin updates, please %s.','xml-sitemap-feed'),
					'<a href="' . admin_url('options-general.php') . '?page=xmlsf_news&tab=license">' . __('correct this issue','xml-sitemap-feed') . '</a>'
				);
				echo '</p></div>';
			}
		);
	}
}

/****************************
* Instantiate updater class *
****************************/

function xmlsf_advanced_news_plugin_updater() {

	// retrieve our license key from the DB
	$data = (array) get_option( 'xmlsf_news_license', array() );

	// check it weekly
	$data = xmlsf_news_check_license( $data );

	$key = isset( $data['key'] ) ? trim( $data['key'] ) : '';
	$status = isset( $data['status'] ) ? $data['status'] : '';

	// don't bother if invalid or missing key
	if ( empty( $key ) || 'invalid' == $status ) return;

	if ( !class_exists( 'EDD_SL_Plugin_Updater' ) ) {
		include XMLSF_NEWS_ADV_DIR . '/vendor/EDD_SL_Plugin_Updater.php';
	}

	// setup the updater
	new EDD_SL_Plugin_Updater(
    XMLSF_NEWS_ADV_STORE_URL,
    XMLSF_NEWS_ADV_FILE,
		array(
			'version' => XMLSF_NEWS_ADV_VERSION, // current version number
			'license' => $key,                   // license key (used get_option above to retrieve from DB)
			'item_id' => XMLSF_NEWS_ADV_ITEM_ID, // ID of the product
			'author'  => 'RavanH',               // author of this plugin
			'beta'    => false,
		)
	);
}

/* TODO Prime meta caches button
if ( isset( $_POST['xmlsf-prime-post-meta'] ) ) {
	if ( xmlsf_verify_nonce('help') ) {
		// prime metadata
		xmlsf_sitemap()->prime_post_meta();
		// TODO split this into post types, and maybe into months?

		// TODO consider same approach for term meta

		add_settings_error( 'prime_meta_notice', 'prime_meta_notice', __('Sitemap post meta cache has been primed.','xml-sitemap-feed'), 'updated' );
	}
}
// ADMIN BUTTON
<input type="submit" name="xmlsf-prime-post-meta" class="button button-small" value="<?php _e( 'Prime post meta caches', 'xml-sitemap-feed' ); ?>" />

/**
 * Prime post images and comment meta data
 *
 * @since 5.2
 *
 * @param string $post_type Post type slug
 * @param intval|null $m Year and month: YYYYMM
 *
public function prime_post_meta( $post_type = 'any', $m = null )
{
	// get our posts
	if ( !is_admin() && is_sitemap() ) {
		// we're a sitemap, so let's work with main query here
		global $wp_query;
		$posts = is_object($wp_query) ? $wp_query->$posts : array();
	} else {
		$args = array(
			'post_type' => $post_type,
			'numberposts' => -1,
			'lang' => '',
			'has_password' => false,
			'update_cache' => false
		);
		if ( is_numeric($m) ) $args['m'] = intval($m);
		$posts = get_posts( $args );

		// try to raise memory limit, context added for filters
		//wp_raise_memory_limit( 'sitemap-posttype-'.$post_type ); // already on admin...
	}

	foreach ( $posts as $post ) {
		if ( ! array_key_exists($post->post_type, $this->post_types) ) continue;

		// Update images meta
		//delete_post_meta( $post->ID, '_xmlsf_image_featured' );
		//delete_post_meta( $post->ID, '_xmlsf_image_attached' );

		if ( !empty($this->post_types[$post->post_type]['tags']['image']) ) {
			$which = $this->post_types[$post->post_type]['tags']['image'];

			$stored = (array) get_post_meta( $post->ID, '_xmlsf_image_'.$which );

			// populate images and add as meta data
			foreach ( xmlsf_images_data( $post, $which ) as $data ) {
				if ( ! in_array( $data, $stored ) )
					add_post_meta( $post->ID, '_xmlsf_image_'.$which, $data );
			}
		}

		// Update last comment date meta
		if ( ! empty($this->post_types[$post->post_type]['update_lastmod_on_comments']) ) {
			// get latest post comment
			$comments = get_comments( array(
				'status' => 'approve',
				'number' => 1,
				'post_id' => $post->ID,
			) );

			if ( isset( $comments[0]->comment_date ) )
				update_post_meta( $post->ID, '_xmlsf_comment_date', $comments[0]->comment_date );
			//else
				//delete_post_meta( $post->ID, '_xmlsf_comment_date' );
		}
	}
}

*/
