<?php
/*
Plugin Name: XML Sitemap & Google News - Google News Advanced
Plugin URI: https://premium.status301.com/downloads/google-news-advanced/
Description: Advanced options for your Google News sitemap
Text Domain: xmlsf-news-advanced
Version: 1.2
Author: RavanH
Author URI: http://status301.net/
*/

define( 'XMLSF_NEWS_ADV_VERSION', '1.2' );
define( 'XMLSF_NEWS_ADV_FILE', __FILE__ );
define( 'XMLSF_NEWS_ADV_DIR', dirname( XMLSF_NEWS_ADV_FILE ) );

define( 'XMLSF_NEWS_ADV_STORE_URL', 'https://premium.status301.com' );
define( 'XMLSF_NEWS_ADV_ITEM_ID', 13480 );

/* --------------------------
 *        INITIALIZE
 * -------------------------- */

function xmlsf_advanced_news() {

	// Upgrade/install, maybe...
	$db_version = get_option( 'xmlsf_advanced_news_version', 0 );
	if ( ! version_compare( XMLSF_NEWS_ADV_VERSION, $db_version, '=' ) ) {
		require_once XMLSF_NEWS_ADV_DIR . '/upgrade.php';
		new XMLSitemapFeed_News_Advanced_Upgrade( $db_version );
	}

	$sitemaps = get_option( 'xmlsf_sitemaps' );

	if ( ! empty( $sitemaps['sitemap-news'] ) ) {
		include XMLSF_NEWS_ADV_DIR . '/controllers/functions.php';
		xmlsf_news_taxonomies();
		add_action( 'xmlsf_ping', 'xmlsf_news_log_ping', 10, 4 );

		include XMLSF_NEWS_ADV_DIR . '/models/functions.php';
		add_filter( 'request', 'xmlsf_advanced_news_filter_request', 1 );
		add_filter( 'xmlsf_news_post_types', 'xmlsf_advanced_news_allow_hierarchical', 11 );
	}
}

add_action( 'init', 'xmlsf_advanced_news', 9 );

/* --------------------------
 *     INITIALIZE ADMIN
 * -------------------------- */

function xmlsf_advanced_news_admin() {

	// adds support link to the plugin meta description
  add_filter( 'plugin_row_meta', function( $links, $file ) {
    if ( $file == plugin_basename( XMLSF_NEWS_ADV_FILE ) ) {
      $links[] = '<a target="_blank" href="https://premium.status301.com/support/forum/xml-sitemap-google-news/google-news/">' . __('Support','xml-sitemap-feed') . '</a>';
    }
    return $links;
  }, 10, 2);

	// Admin message if main plugin is not activated, then short return
	if ( !function_exists('xmlsf_init') ) {
		if ( !file_exists( trailingslashit(WP_PLUGIN_DIR) . 'xml-sitemap-feed/xml-sitemap.php' ) )
			add_action( 'admin_notices', function() {
				add_thickbox();
				include XMLSF_NEWS_ADV_DIR . '/views/admin-notice-install-plugin.php';
			} );
		else
			add_action( 'admin_notices', function() {
				include XMLSF_NEWS_ADV_DIR . '/views/admin-notice-activate-plugin.php';
			} );
		return;
	}
	// Admin message if News Sitemap not activated, then short return
	if ( !class_exists('XMLSF_Sitemap_News') ) {
		add_action( 'admin_notices', function() {
			include XMLSF_NEWS_ADV_DIR . '/views/admin-notice-activate-sitemap.php';
		} );
		return;
	}

	$sitemaps = get_option( 'xmlsf_sitemaps' );

	if ( ! empty( $sitemaps['sitemap-news'] ) ) {
		include XMLSF_NEWS_ADV_DIR . '/controllers/functions.admin.php';
	  include XMLSF_NEWS_ADV_DIR . '/models/functions.admin.php';

		xmlsf_news_license_admin_nag();
	  xmlsf_news_register_settings();
		xmlsf_advanced_news_plugin_updater();

		add_filter( 'xmlsf_news_post_type_field_type', 'xmlsf_news_post_type_field_type' );
	}
}

add_action( 'admin_init', 'xmlsf_advanced_news_admin', 0 );

register_activation_hook( __FILE__, 'xmlsf_news_activate' );

function xmlsf_news_activate() {
	class_exists('XMLSitemapFeed') || activate_plugin( 'xml-sitemap-feed/xml-sitemap-feed.php' );
}
